# Better Web3.py
[![Telegram channel](https://img.shields.io/endpoint?url=https://runkit.io/damiankrawczyk/telegram-badge/branches/master?url=https://t.me/cum_insider)](https://t.me/cum_insider)
[![PyPI version info](https://img.shields.io/pypi/v/better-web3.svg)](https://pypi.python.org/pypi/better-web3)
[![PyPI supported Python versions](https://img.shields.io/pypi/pyversions/better-web3.svg)](https://pypi.python.org/pypi/better-web3)
[![PyPI downloads per month](https://img.shields.io/pypi/dm/better-web3.svg)](https://pypi.python.org/pypi/better-web3)

```bash
pip install better-web3
```

More libraries of the family:
- [tweepy-self](https://github.com/alenkimov/tweepy-self)
- [better-proxy](https://github.com/alenkimov/better_proxy)
